@@ -20,7 +20,7 @@ class AppChooserPortal : public QDBusAbstractAdaptor
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.AppChooser")
 public:
     explicit AppChooserPortal(QObject *parent);
-    ~AppChooserPortal();
+    ~AppChooserPortal() override;
 
 public Q_SLOTS:
     uint ChooseApplication(const QDBusObjectPath &handle,
