@@ -22,8 +22,9 @@ class ScreenCastPortal : public QDBusAbstractAdaptor
 public:
     enum SourceType {
         Any = 0,
-        Monitor,
-        Window,
+        Monitor = 1,
+        Window = 2,
+        Virtual = 4,
     };
     Q_ENUM(SourceType);
     Q_DECLARE_FLAGS(SourceTypes, SourceType)
@@ -35,12 +36,19 @@ public:
     };
     Q_ENUM(CursorModes);
 
+    enum PersistMode {
+        NoPersist = 0,
+        PersistWhileRunning = 1,
+        PersistUntilRevoked = 2,
+    };
+    Q_ENUM(PersistMode);
+
     explicit ScreenCastPortal(QObject *parent);
     ~ScreenCastPortal() override;
 
     uint version() const
     {
-        return 3;
+        return 4;
     }
     uint AvailableSourceTypes() const
     {
